@@ -213,8 +213,8 @@ peas_extension_call_valist (PeasExtension *exten,
 {
   GICallableInfo *callable_info;
   GITypeInfo *retval_info;
-  GArgument *gargs;
-  GArgument retval;
+  GIArgument *gargs;
+  GIArgument retval;
   gpointer retval_ptr;
   gboolean ret;
 
@@ -222,7 +222,10 @@ peas_extension_call_valist (PeasExtension *exten,
   g_return_val_if_fail (method_name != NULL, FALSE);
 
   callable_info = peas_gi_get_method_info (exten->priv->exten_type, method_name);
-  gargs = g_new (GArgument, g_callable_info_get_n_args (callable_info));
+  if (callable_info == NULL)
+    return FALSE;
+
+  gargs = g_newa (GIArgument, g_callable_info_get_n_args (callable_info));
   peas_gi_valist_to_arguments (callable_info, args, gargs, &retval_ptr);
 
   ret = peas_extension_callv (exten, method_name, gargs, &retval);
@@ -234,16 +237,14 @@ peas_extension_call_valist (PeasExtension *exten,
       g_base_info_unref ((GIBaseInfo *) retval_info);
     }
 
-  g_free (gargs);
-
   return ret;
 }
 
 gboolean
 peas_extension_callv (PeasExtension *exten,
                       const gchar   *method_name,
-                      GArgument     *args,
-                      GArgument     *return_value)
+                      GIArgument    *args,
+                      GIArgument    *return_value)
 {
   PeasExtensionClass *klass;
 
